@@ -13,24 +13,22 @@
 #pylint:disable=redefined-outer-name
 
 import os
-from ..jit.annotations import List
+from ..annotations import List, Union
 
 _acceptable_video_formats = ('.mp4', '.avi', '.mov', '.mkv', '.webm')
 _acceptable_image_formats = ('.jpg', '.jpeg', '.png', '.bmp', '.tif', '.tiff')
 
-
 __all__ = [
-    'list_media',
     'list_images',
     'list_videos',
-    'mkdir',
     'listdir',
     'is_image',
     'is_video',
     'isfile',
+    'mkdir',
     'cwd',
     'exists',
-    'minijoin',
+    'join',
     'get_size',
     'chdir',
     'osname',
@@ -38,8 +36,7 @@ __all__ = [
     'dirname'
 ]
 
-
-def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=1) -> List[str]:
+def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=True) -> List[str]:
     r"""
         Lists all image files within a specific directory (and sub-directories if `recursive=True`)
     
@@ -53,13 +50,10 @@ def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbos
         image_files (list): List of names (or full filepaths if `use_fullpath=True`) of the image files
 
     """
-    images = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, verbose=verbose)
-
-    if images is not None:   
-        return images # images is a list
+    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_image_formats, show_size=show_size, verbose=verbose)
 
 
-def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=1) -> List[str]:
+def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=True) -> List[str]:
     r"""
         Lists all video files within a specific directory (and sub-directories if `recursive=True`)
     
@@ -74,150 +68,28 @@ def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbos
 
     """
 
-    videos = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_video_files=True, verbose=verbose)
-
-    if videos is not None:   
-        return videos # videos is a list
+    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_video_formats, show_size=show_size, verbose=verbose)
 
 
-def list_media(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=0) -> List[str]:
+def listdir(
+        DIR : str,
+        recursive : bool = False, 
+        use_fullpath: bool = False, 
+        ext : Union[str, List[str]] = None, 
+        show_size : bool = False, 
+        verbose : bool = True
+    ) -> List[str]:
     r"""
-        Lists all media files within a specific directory (and sub-directories if `recursive=True`)
-    
-    Args:
-        DIR (str): Directory to search for media files
-        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath (bool): Include full filepaths in the returned list (default = False)
-        show_size (bool): Prints the disk size of the media files (default = False)
-    
-    Returns:
-        media_files (list): List of names (or full filepaths if `use_fullpath=True`) of the media files
-
-    """
-
-    media = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, list_video_files=True, verbose=verbose)
-
-    if media is not None:   
-        return media # media is a list
-
-
-def _get_media_from_dir(DIR, recursive=True, use_fullpath=False, show_size=True,  list_image_files=False, list_video_files=False, verbose=1) -> List[str]:
-    r"""
-        Lists all media files within a specific directory (and sub-directories if `recursive=True`)
-    
-    Args:
-        DIR (str): Directory to search for media files
-        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath (bool): Include full filepaths in the returned list (default = False)
-        show_size (bool): Prints the disk size of the media files (default = False)
-    
-    Returns:
-        media_files (list): List of names (or full filepaths if `use_fullpath=True`) of the media files
-
-    """
-
-    if not exists(DIR):
-        raise ValueError('Specified directory does not exist')
-
-    list_media_files = False
-    if list_video_files and list_image_files:
-        list_media_files = True
-    
-    video_files = []
-    image_files = []
-    size_image_list = 0
-    size_video_list = 0
-    
-    if recursive:
-        for root, _, files in os.walk(DIR):
-            for file in files:
-                fullpath = minijoin(root, file).replace('\\', '/')
-                decider = _is_extension_acceptable(file)
-
-                if decider == -1:
-                    continue
-
-                elif decider == 0: # if image
-                    size_image_list += get_size(fullpath, disp_format='mb')
-                    if use_fullpath:
-                        image_files.append(fullpath)
-                    else:
-                        image_files.append(file)
-
-                elif decider == 1: # if video
-                    size_video_list += get_size(fullpath, disp_format='mb')
-                    if use_fullpath:
-                        video_files.append(fullpath)
-                    else:
-                        video_files.append(file)
-
-    else:
-        for file in os.listdir(DIR):
-            fullpath = minijoin(DIR, file).replace('\\', '/')
-            decider = _is_extension_acceptable(file)
-                
-            if decider == -1:
-                continue
-
-            elif decider == 0: # if image
-                size_image_list += get_size(fullpath, disp_format='mb')
-                if use_fullpath:
-                    image_files.append(fullpath)
-                else:
-                    image_files.append(file)
-
-            elif decider == 1: # if video
-                size_video_list += get_size(fullpath, disp_format='mb')
-                if use_fullpath:
-                    video_files.append(fullpath)
-                else:
-                    video_files.append(file)
-
-    count_image_list = len(image_files)
-    count_video_list = len(video_files)
-    
-    if count_image_list == 0 and count_video_list == 0:
-        print('[ERROR] No media files were found')
-
-    else:
-        if list_media_files:
-            if verbose != 0:
-                tot_count = count_image_list + count_video_list
-                print(f'[INFO] {tot_count} files found')
-                if show_size:
-                    tot_size = size_image_list + size_video_list
-                    print(f'[INFO] Total disk size of media files were {tot_size:.2f}Mb ')
-
-            media_files = image_files + video_files
-            return media_files
-
-        elif list_image_files:
-            if verbose != 0:
-                print(f'[INFO] {count_image_list} images found')
-                if show_size:
-                    print(f'[INFO] Total disk size of media files were {size_image_list:.2f}Mb ')
-
-            return image_files
-
-        elif list_video_files:
-            if verbose != 0:
-                print(f'[INFO] {count_video_list} videos found')
-                if show_size:
-                    print(f'[INFO] Total disk size of videos were {size_video_list:.2f}Mb ')
-
-            return video_files
-        
-
-
-def listdir(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=1) -> List[str]:
-    r"""
-        Lists all files within a specific directory (and sub-directories if `recursive=True`)
+        Lists all files within a specific directory (and sub-directories if `recursive=True`).
+        This can be filtered for certain extensions (by populating `ext`)
     
     Args:
         DIR (str): Directory to search for files
         recursive (bool): Indicate whether to search all subdirectories as well (default = False)
         use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        ext (str, list(str), tuple(str)): Filter by extension names.
         show_size (bool): Prints the disk size of the files (default = False)
+        verbose(bool): Print info
     
     Returns:
         files (list): List of names (or full filepaths if `use_fullpath=True`) of the files
@@ -233,17 +105,31 @@ def listdir(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=1)
     if not isinstance(use_fullpath, bool):
         raise ValueError('use_fullpath must be a boolean')
 
+    if ext is not None:
+        if not isinstance(ext, (str, list, tuple)):
+            raise TypeError("`ext` must either be of type `str`, or tuple/list of `str`")
+
+        if isinstance(ext, (list, tuple)):
+            for i in ext:
+                if not isinstance(i, str):
+                    raise TypeError("`ext` must be a homogenous list of `str`")
+
     if not isinstance(show_size, bool):
         raise ValueError('show_size must be a boolean')
+    
+    if not isinstance(verbose, bool):
+        raise ValueError('verbose must be a boolean')
 
-    dirs = []
-    count_files= 0
-    size_dirs_list = 0
+    dirs : list = []
+    count_files : int = 0
+    size_dirs_list : int = 0
     
     if recursive:
         for root, _, files in os.walk(DIR):
             for file in files:
-                fullpath = minijoin(root, file).replace('\\', '/')
+                if ext is not None and not file.endswith(ext):
+                    continue
+                fullpath = join(root, file).replace('\\', '/')
                 size_dirs_list += get_size(fullpath, disp_format='mb')
                 if use_fullpath:
                     dirs.append(fullpath)
@@ -252,14 +138,16 @@ def listdir(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=1)
 
     else:
         for file in os.listdir(DIR):
-            fullpath = minijoin(DIR, file).replace('\\', '/')
+            if ext is not None and not file.endswith(ext):
+                continue
+            fullpath = join(DIR, file).replace('\\', '/')
             size_dirs_list += get_size(fullpath, disp_format='mb')
             if use_fullpath:
                 dirs.append(fullpath)
             else:
                 dirs.append(file)
 
-    if verbose != 0:
+    if verbose:
         count_files = len(dirs)
         if count_files == 1:
             print(f'[INFO] {count_files} file found')
@@ -315,34 +203,6 @@ def is_video(path) -> bool:
     return False
 
 
-def _is_extension_acceptable(path) -> bool:
-    """
-        0 --> Image
-        1 --> Video
-    """
-    # char_total = len(file)
-    # # Finding the last index of '.' to grab the extension
-    # try:
-    #     idx = file.rindex('.')
-    # except ValueError:
-    #     return -1
-    # file_ext = file[idx:char_total]
-
-    # if file_ext in _acceptable_image_formats:
-    #     return 0 
-    # elif file_ext in _acceptable_video_formats:
-    #     return 1
-    # else:
-    #     return -1
-
-    if is_image(path):
-        return 0
-    elif is_video(path):
-        return 1 
-    else:
-        return -1
-
-
 def osname() -> str:
     return os.name
 
@@ -370,9 +230,7 @@ def exists(path) -> bool:
     if not isinstance(path, str):
         raise ValueError('Filepath must be a string')
 
-    if os.path.exists(path):
-        return True 
-    return False
+    return os.path.exists(path)
 
 
 def isfile(path) -> bool:
@@ -471,7 +329,7 @@ def get_size(file, disp_format='bytes') -> float:
         return size * 1e-12
 
 
-def minijoin(*paths) -> str:
+def join(*paths) -> str:
     r"""
         Join multiple filepaths together
 
