@@ -17,12 +17,14 @@ import numpy as np
 
 from .io import imread
 from ._internal import _check_target_size
-from .path import minijoin, list_images
+from .path import join, list_images
 from .color import to_gray
 
 __all__ = [
     'preprocess_from_dir',
     'sep_train',
+    'normalize',
+    'train_val_split'
 ]
 
 
@@ -101,7 +103,7 @@ def preprocess_from_dir(DIR,
         since_preprocess = time.time()
 
         for item in classes:
-            class_path = minijoin(DIR, item)
+            class_path = join(DIR, item)
             class_label = classes.index(item)
             count = 0 
             tens_list = list_images(class_path, use_fullpath=True, verbose=0)
@@ -156,6 +158,16 @@ def preprocess_from_dir(DIR,
 
         return data
 
+def normalize(x, dtype='float32'):
+    """
+    Normalizes the data to mean 0 and standard deviation 1
+    """
+    # x/=255.0 raises a TypeError
+    # x = x/255.0
+    
+    # Converting to float32 and normalizing (float32 saves memory)
+    x = x.astype(dtype) / 255
+    return x
 
 def sep_train(data, IMG_SIZE, channels=1):
     # x = []
