@@ -1,23 +1,26 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
 
 import cv2 as cv 
 import numpy as np 
 
-from ..adorad import Tensor
+from ..coreten import Tensor
 from .position import _proc_in_chunks
 
 
 __all__ = [
-
+    'blur',
+    'gaussian_blur',
+    'median_blur',
+    'motion_blur'
 ]
 
 def blur(tens, ksize) -> Tensor:
