@@ -1,13 +1,13 @@
 #    _____           ______  _____ 
 #  / ____/    /\    |  ____ |  __ \
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
-# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++, Cuda
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
 #  \_____\/_/    \_ \______ |_|  \_
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2020-21 The Caer Authors <http://github.com/jasmcaus>
+# Copyright (c) 2020-2021 The Caer Authors <http://github.com/jasmcaus>
 
 
 from .extract_frames import (
@@ -36,14 +36,8 @@ from .frames_and_fps import (
     __all__ as __all_ffps__
 )
 
-from .stablizer import (
-    Stabilizer,
-    __all__ as __all_st__
-)
 
-
-
-__all__ = __all_extract__ + __all_str__ + __all_live__ + __all_ffps__ + __all_gpu__ + __all_st__
+__all__ = __all_extract__ + __all_str__ + __all_live__ + __all_ffps__ + __all_gpu__
 
 
 # Stop polluting the namespace
@@ -51,5 +45,4 @@ del __all_extract__
 del __all_str__
 del __all_ffps__
 del __all_gpu__
-del __all_live__
-del __all_st__
\ No newline at end of file
+del __all_live__
\ No newline at end of file
